==> abi-0.7.9.tar.gz: abi-0.7.9/src/wp/ap/xp/ap_TB_LabelSet_hu-HU.h <==
/* AbiWord
 * Copyright (C) 2000 AbiSource, Inc.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */

// Hungarian translations provided by Tamas Decsi <tamas@pressflex.com>

/*****************************************************************
******************************************************************
** IT IS IMPORTANT THAT THIS FILE ALLOW ITSELF TO BE INCLUDED
** MORE THAN ONE TIME.
******************************************************************
*****************************************************************/

// Note: if the tooltip is blank, the status message will be used as the
// Note: tooltip.  therefore, we probably don't need most tooltip strings
// Note: here -- unless the status message is too long to look good in
// Note: a tooltip.

// Note: the icon field should not be localized unless absolutely necessary.
// Note: the icon name here is to a specific icon (pixmap or bitmap or whatever)
// Note: that will always be in the application.  if, for example, a big fat 'B'
// Note: for BOLD doesn't make sense in another language, change the entry in
// Note: the localization and add the icon to whatever table.

// Note: if a tool item does not use an icon (like a combo box), use the
// Note: constant "NoIcon" in that column.

// If the second argument is UT_TRUE, then this is the fall-back for
// this language (named in the first two letters).

BeginSet(hu,HU,UT_TRUE)

	ToolbarLabel(AP_TOOLBAR_ID__BOGUS1__,		NULL,		NoIcon,			NULL,NULL)

	//          (id, 		                    szLabel,	IconName,     	szToolTip,      szStatusMsg)

	ToolbarLabel(AP_TOOLBAR_ID_FILE_NEW,		"j", 		tb_new_xpm,		NULL, "j dokumentum ltrehozsa")	
	ToolbarLabel(AP_TOOLBAR_ID_FILE_OPEN,		"Megnyit",		tb_open_xpm,	NULL, "Meglv dokumentum megnyitsa")
	ToolbarLabel(AP_TOOLBAR_ID_FILE_SAVE,		"Ment", 	tb_save_xpm,	NULL, "A dokumentum mentse")
	ToolbarLabel(AP_TOOLBAR_ID_FILE_SAVEAS,		"Ments msknt", 	tb_save_as_xpm,	NULL, "A dokumentum mentse ms nven")
	ToolbarLabel(AP_TOOLBAR_ID_FILE_PRINT,		"Nyomtat",	tb_print_xpm,	NULL, "A dokumentum nyomtatsa")

	ToolbarLabel(AP_TOOLBAR_ID_EDIT_UNDO,		"Visszavon",		tb_undo_xpm,	NULL, "A szerkeszts visszavonsa")
	ToolbarLabel(AP_TOOLBAR_ID_EDIT_REDO,		"jra",		tb_redo_xpm,	NULL, "A szerkeszts ismtelt vgrehajtsa")
	ToolbarLabel(AP_TOOLBAR_ID_EDIT_CUT,		"Kivgs",		tb_cut_xpm,		NULL, "Kivgs")
	ToolbarLabel(AP_TOOLBAR_ID_EDIT_COPY,		"Msols",		tb_copy_xpm,	NULL, "Msols")
	ToolbarLabel(AP_TOOLBAR_ID_EDIT_PASTE,		"Beilleszts",	tb_paste_xpm,	NULL, "Beilleszts")

	ToolbarLabel(AP_TOOLBAR_ID_FMT_STYLE,		"Stlus",	NoIcon,			NULL, "Stlus")
	ToolbarLabel(AP_TOOLBAR_ID_FMT_FONT,		"Bettpus",		NoIcon,			NULL, "Bettpus")
	ToolbarLabel(AP_TOOLBAR_ID_FMT_SIZE,		"Bet Mret", NoIcon,		NULL, "Bet Mret")
	ToolbarLabel(AP_TOOLBAR_ID_FMT_BOLD,		"Flkvr",		tb_text_bold_F_xpm,		NULL, "Flkvr")
	ToolbarLabel(AP_TOOLBAR_ID_FMT_ITALIC,		"Dlt",	tb_text_italic_D_xpm,	NULL, "Dlt")
	ToolbarLabel(AP_TOOLBAR_ID_FMT_UNDERLINE,	"Alhzott",tb_text_underline_A_xpm,	NULL, "Alhzott")
	ToolbarLabel(AP_TOOLBAR_ID_FMT_OVERLINE,	"Fellvons",tb_text_overline_F_xpm,	NULL, "Fellvons")
	ToolbarLabel(AP_TOOLBAR_ID_FMT_STRIKE,		"Kihzott",   tb_text_strikeout_K_xpm,	NULL, "Kihzott")

	ToolbarLabel(AP_TOOLBAR_ID_FMT_SUPERSCRIPT,	"Fels index",	tb_text_superscript_xpm,	NULL, "Fels index")
	ToolbarLabel(AP_TOOLBAR_ID_FMT_SUBSCRIPT,	"Als index",	tb_text_subscript_xpm,		NULL, "Als index")

	ToolbarLabel(AP_TOOLBAR_ID_ALIGN_LEFT,		"Balra",		tb_text_align_left_xpm,		NULL, "Balra igazts")
	ToolbarLabel(AP_TOOLBAR_ID_ALIGN_CENTER,	"Kzpre",	tb_text_center_xpm,	NULL, "Kzpre igazts")
	ToolbarLabel(AP_TOOLBAR_ID_ALIGN_RIGHT,		"Jobbra",	tb_text_align_right_xpm,	NULL, "Jobbra igazts")
	ToolbarLabel(AP_TOOLBAR_ID_ALIGN_JUSTIFY,	"Sorkiegyenlts",	tb_text_justify_xpm,	NULL, "A bekezds sorkiegyenltse")

	ToolbarLabel(AP_TOOLBAR_ID_PARA_0BEFORE,	"None before",		tb_para_0before_xpm,	NULL, "Space before: None")
	ToolbarLabel(AP_TOOLBAR_ID_PARA_12BEFORE,	"12 pt before",		tb_para_12before_xpm,	NULL, "Space before: 12 pt")

	ToolbarLabel(AP_TOOLBAR_ID_SINGLE_SPACE,	"Szimpla sorkz",	tb_line_single_space_xpm,	NULL, "Szimpla sorkz")
	ToolbarLabel(AP_TOOLBAR_ID_MIDDLE_SPACE,	"1,5 sor",		tb_line_middle_space_xpm,	NULL, "1,5 sor")
	ToolbarLabel(AP_TOOLBAR_ID_DOUBLE_SPACE,	"Dupla sorkz",	tb_line_double_space_xpm,	NULL, "Dupla sorkz")

	ToolbarLabel(AP_TOOLBAR_ID_1COLUMN,			"1 Hasb",			tb_1column_xpm,			NULL, "1 Hasb")
	ToolbarLabel(AP_TOOLBAR_ID_2COLUMN,			"2 Hasb",		tb_2column_xpm,			NULL, "2 Hasb")
	ToolbarLabel(AP_TOOLBAR_ID_3COLUMN,			"3 Hasb",		tb_3column_xpm,			NULL, "3 Hasb")

	ToolbarLabel(AP_TOOLBAR_ID_ZOOM,			"Nagyts",		NoIcon,			NULL, "Nagyts")
	
	// ... add others here ...

	ToolbarLabel(AP_TOOLBAR_ID__BOGUS2__,		NULL,		NoIcon,			NULL,NULL)

EndSet()

==> abi-0.7.12.tar.gz: abi-0.7.12/src/wp/ap/xp/ap_TB_LabelSet_hu-HU.h <==
/* AbiWord
 * Copyright (C) 2000 AbiSource, Inc.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */

// Hungarian translations provided by Tamas Decsi <tamas.decsi@techie.com>

/*****************************************************************
******************************************************************
** IT IS IMPORTANT THAT THIS FILE ALLOW ITSELF TO BE INCLUDED
** MORE THAN ONE TIME.
******************************************************************
*****************************************************************/

// Note: if the tooltip is blank, the status message will be used as the
// Note: tooltip.  therefore, we probably don't need most tooltip strings
// Note: here -- unless the status message is too long to look good in
// Note: a tooltip.

// Note: the icon field should not be localized unless absolutely necessary.
// Note: the icon name here is to a specific icon (pixmap or bitmap or whatever)
// Note: that will always be in the application.  if, for example, a big fat 'B'
// Note: for BOLD doesn't make sense in another language, change the entry in
// Note: the localization and add the icon to whatever table.

// Note: if a tool item does not use an icon (like a combo box), use the
// Note: constant "NoIcon" in that column.

// If the second argument is UT_TRUE, then this is the fall-back for
// this language (named in the first two letters).

BeginSet(hu,HU,UT_TRUE)

	ToolbarLabel(AP_TOOLBAR_ID__BOGUS1__,		NULL,		NoIcon,			NULL,NULL)

	//          (id, 		                    szLabel,	IconName,     	szToolTip,      szStatusMsg)

	ToolbarLabel(AP_TOOLBAR_ID_FILE_NEW,		"j", 		tb_new_xpm,		NULL, "j dokumentum ltrehozsa")	
	ToolbarLabel(AP_TOOLBAR_ID_FILE_OPEN,		"Megnyit",		tb_open_xpm,	NULL, "Meglv dokumentum megnyitsa")
	ToolbarLabel(AP_TOOLBAR_ID_FILE_SAVE,		"Ment", 	tb_save_xpm,	NULL, "A dokumentum mentse")
	ToolbarLabel(AP_TOOLBAR_ID_FILE_SAVEAS,		"Ments msknt", 	tb_save_as_xpm,	NULL, "A dokumentum mentse ms nven")
	ToolbarLabel(AP_TOOLBAR_ID_FILE_PRINT,		"Nyomtat",	tb_print_xpm,	NULL, "A dokumentum nyomtatsa")

	ToolbarLabel(AP_TOOLBAR_ID_EDIT_UNDO,		"Visszavon",		tb_undo_xpm,	NULL, "A szerkeszts visszavonsa")
	ToolbarLabel(AP_TOOLBAR_ID_EDIT_REDO,		"jra",		tb_redo_xpm,	NULL, "A szerkeszts ismtelt vgrehajtsa")
	ToolbarLabel(AP_TOOLBAR_ID_EDIT_CUT,		"Kivgs",		tb_cut_xpm,		NULL, "Kivgs")
	ToolbarLabel(AP_TOOLBAR_ID_EDIT_COPY,		"Msols",		tb_copy_xpm,	NULL, "Msols")
	ToolbarLabel(AP_TOOLBAR_ID_EDIT_PASTE,		"Beilleszts",	tb_paste_xpm,	NULL, "Beilleszts")

	ToolbarLabel(AP_TOOLBAR_ID_FMT_STYLE,		"Stlus",	NoIcon,			NULL, "Stlus")
	ToolbarLabel(AP_TOOLBAR_ID_FMT_FONT,		"Bettpus",		NoIcon,			NULL, "Bettpus")
	ToolbarLabel(AP_TOOLBAR_ID_FMT_SIZE,		"Bet Mret", NoIcon,		NULL, "Bet Mret")
	ToolbarLabel(AP_TOOLBAR_ID_FMT_BOLD,		"Flkvr",		tb_text_bold_F_xpm,		NULL, "Flkvr")
	ToolbarLabel(AP_TOOLBAR_ID_FMT_ITALIC,		"Dlt",	tb_text_italic_D_xpm,	NULL, "Dlt")
	ToolbarLabel(AP_TOOLBAR_ID_FMT_UNDERLINE,	"Alhzott",tb_text_underline_A_xpm,	NULL, "Alhzott")
	ToolbarLabel(AP_TOOLBAR_ID_FMT_OVERLINE,	"Fellvons",tb_text_overline_F_xpm,	NULL, "Fellvons")
	ToolbarLabel(AP_TOOLBAR_ID_FMT_STRIKE,		"Kihzott",   tb_text_strikeout_K_xpm,	NULL, "Kihzott")

	ToolbarLabel(AP_TOOLBAR_ID_FMT_SUPERSCRIPT,	"Fels index",	tb_text_superscript_xpm,	NULL, "Fels index")
	ToolbarLabel(AP_TOOLBAR_ID_FMT_SUBSCRIPT,	"Als index",	tb_text_subscript_xpm,		NULL, "Als index")
	ToolbarLabel(AP_TOOLBAR_ID_INSERT_SYMBOL,	"Szimblum",	tb_symbol_xpm,		NULL, "Szimblum beillesztse")

	ToolbarLabel(AP_TOOLBAR_ID_ALIGN_LEFT,		"Balra",		tb_text_align_left_xpm,		NULL, "Balra igazts")
	ToolbarLabel(AP_TOOLBAR_ID_ALIGN_CENTER,	"Kzpre",	tb_text_center_xpm,	NULL, "Kzpre igazts")
	ToolbarLabel(AP_TOOLBAR_ID_ALIGN_RIGHT,		"Jobbra",	tb_text_align_right_xpm,	NULL, "Jobbra igazts")
	ToolbarLabel(AP_TOOLBAR_ID_ALIGN_JUSTIFY,	"Sorkiegyenlts",	tb_text_justify_xpm,	NULL, "A bekezds sorkiegyenltse")

	ToolbarLabel(AP_TOOLBAR_ID_PARA_0BEFORE,	"Nincs eltte",		tb_para_0before_xpm,	NULL, "Nincs eltte hely")
	ToolbarLabel(AP_TOOLBAR_ID_PARA_12BEFORE,	"12 pont eltte",		tb_para_12before_xpm,	NULL, "12 pont hely van eltte")

	ToolbarLabel(AP_TOOLBAR_ID_SINGLE_SPACE,	"Szimpla sorkz",	tb_line_single_space_xpm,	NULL, "Szimpla sorkz")
	ToolbarLabel(AP_TOOLBAR_ID_MIDDLE_SPACE,	"1,5 sor",		tb_line_middle_space_xpm,	NULL, "1,5 sor")
	ToolbarLabel(AP_TOOLBAR_ID_DOUBLE_SPACE,	"Dupla sorkz",	tb_line_double_space_xpm,	NULL, "Dupla sorkz")

	ToolbarLabel(AP_TOOLBAR_ID_1COLUMN,			"1 Hasb",			tb_1column_xpm,			NULL, "1 Hasb")
	ToolbarLabel(AP_TOOLBAR_ID_2COLUMN,			"2 Hasb",		tb_2column_xpm,			NULL, "2 Hasb")
	ToolbarLabel(AP_TOOLBAR_ID_3COLUMN,			"3 Hasb",		tb_3column_xpm,			NULL, "3 Hasb")

	ToolbarLabel(AP_TOOLBAR_ID_ZOOM,			"Nagyts",		NoIcon,			NULL, "Nagyts")
	ToolbarLabel(AP_TOOLBAR_ID_LISTS_BULLETS,		"Felsorolsok",		tb_lists_bullets_xpm,		NULL,		"Felsorolsok kezdse/lezrsa")
	ToolbarLabel(AP_TOOLBAR_ID_LISTS_NUMBERS,		"Sorszmozott Listk",		tb_lists_numbers_xpm,		NULL,		"Sorszmozott Listk kezdse/lezrsa")
	
	// ... add others here ...

	ToolbarLabel(AP_TOOLBAR_ID__BOGUS2__,		NULL,		NoIcon,			NULL,NULL)

EndSet()
